/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
export declare type EntangledPairArgs = {
    treasuryMint: web3.PublicKey;
    mintA: web3.PublicKey;
    mintB: web3.PublicKey;
    tokenAEscrow: web3.PublicKey;
    tokenBEscrow: web3.PublicKey;
    authority: web3.PublicKey;
    bump: number;
    tokenAEscrowBump: number;
    tokenBEscrowBump: number;
    price: beet.bignum;
    paid: boolean;
    paysEveryTime: boolean;
};
export declare class EntangledPair implements EntangledPairArgs {
    readonly treasuryMint: web3.PublicKey;
    readonly mintA: web3.PublicKey;
    readonly mintB: web3.PublicKey;
    readonly tokenAEscrow: web3.PublicKey;
    readonly tokenBEscrow: web3.PublicKey;
    readonly authority: web3.PublicKey;
    readonly bump: number;
    readonly tokenAEscrowBump: number;
    readonly tokenBEscrowBump: number;
    readonly price: beet.bignum;
    readonly paid: boolean;
    readonly paysEveryTime: boolean;
    private constructor();
    static fromArgs(args: EntangledPairArgs): EntangledPair;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [EntangledPair, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<EntangledPair>;
    static deserialize(buf: Buffer, offset?: number): [EntangledPair, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        treasuryMint: string;
        mintA: string;
        mintB: string;
        tokenAEscrow: string;
        tokenBEscrow: string;
        authority: string;
        bump: number;
        tokenAEscrowBump: number;
        tokenBEscrowBump: number;
        price: number | {
            toNumber: () => number;
        };
        paid: boolean;
        paysEveryTime: boolean;
    };
}
export declare const entangledPairBeet: beet.BeetStruct<EntangledPair, EntangledPairArgs & {
    accountDiscriminator: number[];
}>;
